@@ -22,7 +22,7 @@ from .utils import convert_from_cb, convert_to_cb
 import yaml
 import json
 import time
-from .errors import ApiError, ServerError, InvalidObjectError, MoreThanOneResultError, ObjectNotFoundError
+from .errors import ApiError, ServerError, InvalidObjectError, MoreThanOneResultError, ObjectNotFoundError, TimeoutError
 import logging
 from datetime import datetime
 from solrq import Q
@@ -351,6 +351,10 @@ class NewBaseModel(object, metaclass=CbMetaModel):
     """Base class of all model objects within the Carbon Black Cloud SDK."""
     primary_key = "id"
 
+    # Constants for tuning string representations
+    MAX_VALUE_WIDTH = 50
+    MAX_LIST_ITEM_RENDER = 3
+
     def __init__(self, cb, model_unique_id=None, initial_data=None, force_init=False, full_doc=False):
         """
         Initialize the NewBaseModel object.
@@ -551,6 +555,158 @@ class NewBaseModel(object, metaclass=CbMetaModel):
             return "<%s.%s object at %s> @ %s" % (self.__class__.__module__, self.__class__.__name__, hex(id(self)),
                                                   self._cb.session.server)
 
+    def _subobject(self, name):
+        """
+        Returns the "subobject value" of the given attribute.
+
+        Args:
+            name (str): Name of the subobject value to be returned.
+
+        Returns:
+            Any: Subobject value for the attribute, or None if there is none.
+
+        Notes:
+            Should be overridden for any class wanting to use subobject reporting capabilities.
+            If the attribute is a list of subobjects, this method should return that list.
+            If the attribute is a single subobject, this method should return that subobject.
+        """
+        return None
+
+    @classmethod
+    def _str_stringize(cls, value):
+        """
+        Returns the "stringized" representation of an attribute value, truncated if it's too long.
+
+        Args:
+            value (Any): Value to be stringized.
+
+        Returns:
+            str: The string equivalent.
+        """
+        try:
+            string_value = str(value)
+        except UnicodeDecodeError:
+            string_value = repr(value)
+        if len(string_value) > NewBaseModel.MAX_VALUE_WIDTH:
+            string_value = string_value[:NewBaseModel.MAX_VALUE_WIDTH - 3] + "..."
+        return string_value
+
+    @classmethod
+    def _str_name_field_len(cls, attributes):
+        """
+        Given an attribute dictionary, returns the maximum length of its "name" field.
+
+        Args:
+            attributes (dict): A dictionary to check.
+
+        Returns:
+            int: The maximum length of any key in the dictionary.
+        """
+        attr_names = []
+        for attr in attributes:
+            if isinstance(attr, str):
+                attr_names.append(attr)
+            elif isinstance(attr, dict):
+                attr_names.extend(attr.keys())
+        return max([len(s) for s in attr_names]) if attr_names else 0
+
+    def _str_attr_line(self, name, value, name_field_len, top_level=True):
+        """
+        Returns the representation of a single attribute within an object (which may be multiple lines).
+
+        Args:
+            name (str): The name of this attribute.
+            value (Any): The value of this attribute.
+            name_field_len (int): Size of the name field for this line.
+            top_level (bool): True if this is a "top level" object being rendered as lines of text.
+
+        Returns:
+            list[str]: The list of lines of text in the attribute representation.
+        """
+        lines = []
+        sub_format_str = "{1:s}: {2:s}"
+        format_str = "{0:3s} " + sub_format_str if top_level else sub_format_str
+        status = ''
+        if top_level and name in self._dirty_attributes:
+            if self._dirty_attributes[name] is None:
+                status = "(+)"
+            else:
+                status = "(*)"
+        subobject_value = self._subobject(name) if top_level else None
+        spacing = name_field_len + (6 if top_level else 2)  # (status + space) + name + colon + space
+        if isinstance(value, list):
+            # this is a list - render the first three items, then [...] if we have more
+            target = value if subobject_value is None else subobject_value
+            list_header = f"[list:{len(target)} {'item' if len(target) == 1 else 'items'}]" \
+                          f"{':' if len(target) > 0 else ''}"
+            lines.append(format_str.format(status, name.rjust(name_field_len), list_header))
+            for index, item in enumerate(target):
+                if index >= NewBaseModel.MAX_LIST_ITEM_RENDER:
+                    # punt the rest of the list
+                    lines.append(f"{' ' * spacing}[...]")
+                    break
+                if subobject_value is not None:
+                    # render the item as a subobject
+                    lines.append((' ' * spacing) + sub_format_str.format('', f"[{index}]",
+                                                                         f"[{item.__class__.__name__} object]:"))
+                    lines.extend([f"{' ' * (spacing + 5)}{sub_line}"
+                                  for sub_line in self._str_dict_lines(item._info, False)])
+                    lines.append('')
+                else:
+                    # render item normally
+                    lines.append((' ' * spacing) + sub_format_str.format('', f"[{index}]", self._str_stringize(item)))
+        elif subobject_value is not None:
+            # this is a subobject
+            lines.append(format_str.format(status, name.rjust(name_field_len),
+                                           f"[{subobject_value.__class__.__name__} object]:"))
+            lines.extend([f"{' ' * spacing}{sub_line}"
+                          for sub_line in self._str_dict_lines(subobject_value._info, False)])
+            lines.append('')
+        elif isinstance(value, dict) and top_level:
+            # append the dict elements
+            lines.append(format_str.format(status, name.rjust(name_field_len), '[dict] {'))
+            if len(value) > 0:
+                lines.extend([f"{' ' * (spacing + 4)}{sub_line}" for sub_line in self._str_dict_lines(value, False)])
+            lines.append(f"{' ' * spacing}{'}'}")
+        else:
+            # ordinary case
+            lines.append(format_str.format(status, name.rjust(name_field_len), self._str_stringize(value)))
+        return lines
+
+    def _str_dict_lines(self, d, top_level=True):
+        """
+        Returns the representation of all attributes within a dictionary.
+
+        Args:
+            d (dict): The dictionary from which the attributes are to be rendered.
+            top_level (bool): True if this is a "top level" object being rendered as lines of text.
+
+        Returns:
+            list[str]: The list of lines of test in the attribute representation.
+        """
+        # for dictionaries that can be sorted, sort them
+        lines = []
+        try:
+            attributes = sorted(d)
+        # dictionaries containing dictionaries cannot be sorted, so leave as is
+        except:
+            attributes = d
+
+        # Compute the name field length.
+        name_field_len = self._str_name_field_len(attributes)
+
+        for attr in attributes:
+            # typical case, where the info dictionary value for this `attr` is a string
+            if isinstance(attr, str):
+                lines.extend(self._str_attr_line(attr, d[attr], name_field_len, top_level))
+            # edge case (seen in Facet searches) where the info dictionary value for this `attr` is a dictionary
+            elif isinstance(attr, dict):
+                # go through each attribute in the `attr` dictionary
+                for att in attr:
+                    lines.extend(self._str_attr_line(att, attr[att], name_field_len, top_level))
+
+        return lines
+
     def __str__(self):
         """
         Returns a string representation of the object.
@@ -558,56 +714,18 @@ class NewBaseModel(object, metaclass=CbMetaModel):
         Returns:
             str: A string representation of the object.
         """
-        lines = []
-        lines.append("{0:s} object, bound to {1:s}.".format(self.__class__.__name__, self._cb.session.server))
+        # generate the "header"
+        lines = ["{0:s} object, bound to {1:s}.".format(self.__class__.__name__, self._cb.session.server)]
         if not issubclass(type(self), UnrefreshableModel):
             if self._last_refresh_time:
                 lines.append(" Last refreshed at {0:s}".format(time.ctime(self._last_refresh_time)))
             if not self._full_init:
                 lines.append(" Partially initialized. Use .refresh() to load all attributes")
-        lines.append("-" * 79)
-        lines.append("")
+        lines.append('-' * 79)
+        lines.append('')
 
-        # for dictionaries that can be sorted, sort them
-        try:
-            attributes = sorted(self._info)
-        # dictionaries containing dictionaries cannot be sorted, so leave as is
-        except:
-            attributes = self._info
-
-        for attr in attributes:
-            # typical case, where the info dictionary value for this `attr` is a string
-            if isinstance(attr, str):
-                status = "   "
-                if attr in self._dirty_attributes:
-                    if self._dirty_attributes[attr] is None:
-                        status = "(+)"
-                    else:
-                        status = "(*)"
-                try:
-                    val = str(self._info[attr])
-                except UnicodeDecodeError:
-                    val = repr(self._info[attr])
-                if len(val) > 50:
-                    val = val[:47] + u"..."
-                lines.append(u"{0:s} {1:>20s}: {2:s}".format(status, attr, val))
-            # edge case (seen in Facet searches) where the info dictionary value for this `attr` is a dictionary
-            elif isinstance(attr, dict):
-                # go through each attribute in the `attr` dictionary
-                for att in attr:
-                    status = "   "
-                    if att in self._dirty_attributes:
-                        if self._dirty_attributes[att] is None:
-                            status = "(+)"
-                        else:
-                            status = "(*)"
-                    try:
-                        val = str(attr[att])
-                    except UnicodeDecodeError:
-                        val = repr(attr[att])
-                    if len(val) > 50:
-                        val = val[:47] + u"..."
-                    lines.append(u"{0:s} {1:>20s}: {2:s}".format(status, att, val))
+        # add the attribute lines
+        lines.extend(self._str_dict_lines(self._info))
 
         return "\n".join(lines)
 
@@ -925,10 +1043,23 @@ class IterableQueryMixin:
         Returns:
             object: Either an item or a list of items.
         """
-        results = list(self)
         if isinstance(item, slice):
+            try:
+                if item.start is not None and item.start >= 0 or item.stop is not None and item.stop >= 0:
+                    from_row = 0
+                    max_rows = -1
+                    if item.start:
+                        from_row = item.start
+                    if item.stop:
+                        max_rows = item.stop - from_row
+                    results = list(self._perform_query(from_row=from_row, max_rows=max_rows))
+                    return results
+            except TypeError:
+                log.debug(f"Unable to perform optimized query for {self.__class__.__name__}")
+            results = list(self)
             return [results[ii] for ii in range(*item.indices(len(results)))]
         elif isinstance(item, int):
+            results = list(self._perform_query(from_row=item, max_rows=1))
             return results[item]
         else:
             raise TypeError("Invalid argument type")
