@@ -52,6 +52,7 @@ from .base import CreatableModelMixin
 from .utils import convert_query_params
 
 log = logging.getLogger(__name__)
+DEFAULT_STREAM_BUFFER_SIZE = 1024
 
 
 def try_json(resp):
@@ -210,6 +211,7 @@ class Connection(object):
             credentials.use_custom_proxy_session = False
 
         self._timeout = timeout
+        self.stream_buffer_size = DEFAULT_STREAM_BUFFER_SIZE
 
         if max_retries is None:
             max_retries = MAX_RETRIES
@@ -269,6 +271,7 @@ class Connection(object):
 
         verify_ssl = kwargs.pop('verify', None) or self.ssl_verify
         proxies = kwargs.pop('proxies', None) or self.proxies
+        stream = kwargs.pop('stream', False)
 
         new_headers = kwargs.pop('headers', None)
         if new_headers:
@@ -284,7 +287,7 @@ class Connection(object):
             if raw_data:
                 log.debug("Sending HTTP {0} {1} with {2}".format(method, url, raw_data))
             r = self.session.request(method, uri, headers=headers, verify=verify_ssl, proxies=proxies,
-                                     timeout=self._timeout, **kwargs)
+                                     timeout=self._timeout, stream=stream, **kwargs)
             log.debug('HTTP {0:s} {1:s} took {2:.3f}s (response {3:d})'.format(method, url,
                                                                                r.elapsed.total_seconds(),
                                                                                r.status_code))
@@ -523,6 +526,65 @@ class BaseAPI(object):
 
         return result
 
+    def api_request_stream(self, method, uri, stream_output, **kwargs):
+        """
+        Submit a request to the specified URI and stream the results back into the given stream object.
+
+        Args:
+            method (str): HTTP method to use.
+            uri (str): The URI to send the request to.
+            stream_output (RawIOBase): The output stream to write the data to.
+            **kwargs (dict): Additional arguments for the request.
+
+        Returns:
+            object: The return data from the request.
+        """
+        headers = kwargs.pop("headers", {})
+        raw_data = None
+
+        if method in ('POST', 'PUT', 'PATCH'):
+            if "Content-Type" not in headers:
+                headers["Content-Type"] = "application/json"
+                raw_data = json.dumps(kwargs.pop("data", {}), sort_keys=True)
+        else:
+            if 'data' in kwargs:
+                del kwargs['data']
+
+        with self.session.http_request(method, uri, headers=headers, data=raw_data, stream=True, **kwargs) as resp:
+            for block in resp.iter_content(self.session.stream_buffer_size):
+                stream_output.write(block)
+        return resp
+
+    def api_request_iterate(self, method, uri, **kwargs):
+        """
+        Submit a request to the specified URI and iterate over the response as lines of text.
+
+        Should only be used for requests that can be expressed as large amounts of text that can be broken into lines.
+        Since this is an iterator, call it with the 'yield from' syntax.
+
+        Args:
+            method (str): HTTP method to use.
+            uri (str): The URI to send the request to.
+            **kwargs (dict): Additional arguments for the request.
+
+        Returns:
+            iterable: An iterable that can be used to get each line of text in turn as a string.
+        """
+        headers = kwargs.pop("headers", {})
+        raw_data = None
+
+        if method in ('POST', 'PUT', 'PATCH'):
+            if "Content-Type" not in headers:
+                headers["Content-Type"] = "application/json"
+                raw_data = json.dumps(kwargs.pop("data", {}), sort_keys=True)
+        else:
+            if 'data' in kwargs:
+                del kwargs['data']
+
+        with self.session.http_request(method, uri, headers=headers, data=raw_data, stream=True, **kwargs) as resp:
+            for line in resp.iter_lines(decode_unicode=True):
+                yield line
+
     def post_object(self, uri, body, **kwargs):
         """
         Send a POST request to the specified URI.
@@ -530,7 +592,7 @@ class BaseAPI(object):
         Args:
             uri (str): The URI to send the POST request to.
             body (object): The data to be sent in the body of the POST request.
-            **kwargs:
+            **kwargs (dict): Additional arguments for the HTTP POST.
 
         Returns:
             object: The return data from the POST request.
