@@ -645,6 +645,20 @@ class Feed(FeedModel):
         """
         return FeedQuery(self, cb)
 
+    def _subobject(self, name):
+        """
+        Returns the "subobject value" of the given attribute.
+
+        Args:
+            name (str): Name of the subobject value to be returned.
+
+        Returns:
+            Any: Subobject value for the attribute, or None if there is none.
+        """
+        if name == 'reports':
+            return self._reports
+        return super(Feed, self)._subobject(name)
+
     def save(self, public=False):
         """
         Saves this feed on the Enterprise EDR server.
@@ -911,10 +925,9 @@ class Report(FeedModel):
         self._feed_id = feed_id
         self._from_watchlist = from_watchlist
 
-        if self.iocs:
-            self._iocs = IOC(cb, initial_data=self.iocs, report_id=self.id)
-        if self.iocs_v2:
-            self._iocs_v2 = [IOC_V2(cb, initial_data=ioc, report_id=self.id) for ioc in self.iocs_v2]
+        self._iocs = IOC(cb, initial_data=self.iocs, report_id=self.id) if self.iocs else None
+        self._iocs_v2 = [IOC_V2(cb, initial_data=ioc, report_id=self.id) for ioc in self.iocs_v2] \
+            if self.iocs_v2 else None
         # this flag is set when we need to rebuild the 'ioc_v2' element of _info from the _iocs_v2 array
         self._iocs_v2_need_rebuild = False
 
@@ -1069,6 +1082,22 @@ class Report(FeedModel):
         return Report.ReportBuilder(cb, {'title': title, 'description': description, 'severity': severity,
                                          'timestamp': timestamp, 'tags': tags if tags else []})
 
+    def _subobject(self, name):
+        """
+        Returns the "subobject value" of the given attribute.
+
+        Args:
+            name (str): Name of the subobject value to be returned.
+
+        Returns:
+            Any: Subobject value for the attribute, or None if there is none.
+        """
+        if name == 'iocs':
+            return self._iocs
+        if name == 'iocs_v2':
+            return self._iocs_v2
+        return super(Report, self)._subobject(name)
+
     def save_watchlist(self):
         """
         Saves this report *as a watchlist report*.
@@ -1200,13 +1229,11 @@ class Report(FeedModel):
     def ignored(self):
         """Returns the ignore status for this report.
 
-        Only watchlist reports have an ignore status.
-
         Returns:
             (bool): True if this Report is ignored, False otherwise.
 
         Raises:
-            InvalidObjectError: If `id` is missing or this Report is not from a Watchlist.
+            InvalidObjectError: If `id` is missing or feed ID is missing.
 
         Example:
 
@@ -1215,12 +1242,16 @@ class Report(FeedModel):
         """
         if not self.id:
             raise InvalidObjectError("missing Report ID")
-        if not self._from_watchlist:
-            raise InvalidObjectError("ignore status only applies to watchlist reports")
+        if self._feed_id:
+            send_id = f"{self._feed_id}-{self.id}"
+        elif self._from_watchlist:
+            send_id = self.id
+        else:
+            raise InvalidObjectError("missing Feed ID")
 
         url = "/threathunter/watchlistmgr/v3/orgs/{}/reports/{}/ignore".format(
             self._cb.credentials.org_key,
-            self.id
+            send_id
         )
         resp = self._cb.get_object(url)
         return resp["ignored"]
@@ -1228,40 +1259,42 @@ class Report(FeedModel):
     def ignore(self):
         """Sets the ignore status on this report.
 
-        Only watchlist reports have an ignore status.
-
         Raises:
-            InvalidObjectError: If `id` is missing or this Report is not from a Watchlist.
+            InvalidObjectError: If `id` is missing or feed ID is missing.
         """
         if not self.id:
             raise InvalidObjectError("missing Report ID")
-
-        if not self._from_watchlist:
-            raise InvalidObjectError("ignoring only applies to watchlist reports")
+        if self._feed_id:
+            send_id = f"{self._feed_id}-{self.id}"
+        elif self._from_watchlist:
+            send_id = self.id
+        else:
+            raise InvalidObjectError("missing Feed ID")
 
         url = "/threathunter/watchlistmgr/v3/orgs/{}/reports/{}/ignore".format(
             self._cb.credentials.org_key,
-            self.id
+            send_id
         )
         self._cb.put_object(url, None)
 
     def unignore(self):
         """Removes the ignore status on this report.
 
-        Only watchlist reports have an ignore status.
-
         Raises:
-            InvalidObjectError: If `id` is missing or this Report is not from a Watchlist.
+            InvalidObjectError: If `id` is missing or feed ID is missing.
         """
         if not self.id:
             raise InvalidObjectError("missing Report ID")
-
-        if not self._from_watchlist:
-            raise InvalidObjectError("ignoring only applies to watchlist reports")
+        if self._feed_id:
+            send_id = f"{self._feed_id}-{self.id}"
+        elif self._from_watchlist:
+            send_id = self.id
+        else:
+            raise InvalidObjectError("missing Feed ID")
 
         url = "/threathunter/watchlistmgr/v3/orgs/{}/reports/{}/ignore".format(
             self._cb.credentials.org_key,
-            self.id
+            send_id
         )
         self._cb.delete_object(url)
 
@@ -1639,15 +1672,15 @@ class IOC_V2(FeedModel):
 
     def validate(self):
         """
-        Checks to ensure this IOC contains valid data.
+        Checks to ensure this IOC contains valid FQDN.
 
         Raises:
             InvalidObjectError: If the IOC contains invalid data.
         """
         super(IOC_V2, self).validate()
 
-        if self.link and not validators.url(self.link):
-            raise InvalidObjectError("link should be a valid URL")
+        if self.link and not validators.domain(self.link):
+            raise InvalidObjectError("link should be a valid domain URL (FQDN)")
 
     @property
     def ignored(self):
