@@ -108,7 +108,7 @@ class Binary(UnrefreshableModel):
         else:
             return next((item.url
                         for item in downloads.found
-                        if self.sha256 == item.sha256), None)
+                        if self.sha256.upper() == item.sha256.upper()), None)
 
 
 class Downloads(UnrefreshableModel):
